package com.dcsoft.system.face.service.impl;

import java.util.List;

import com.dcsoft.system.face.domain.FaceRule;
import com.dcsoft.system.face.mapper.FaceRuleMapper;
import com.dcsoft.system.face.service.IFaceRuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * ruleService业务层处理
 *
 * @author nichun
 * @date 2023-04-19
 */
@Service
public class FaceRuleServiceImpl implements IFaceRuleService
{
    @Autowired
    private FaceRuleMapper faceRuleMapper;

    /**
     * 查询rule
     *
     * @param ftrx rule主键
     * @return rule
     */
    @Override
    public FaceRule selectFaceRuleByFtrx(String ftrx)
    {
        return faceRuleMapper.selectFaceRuleByFtrx(ftrx);
    }

    /**
     * 查询rule列表
     *
     * @param faceRule rule
     * @return rule
     */
    @Override
    public List<FaceRule> selectFaceRuleList(FaceRule faceRule)
    {
        return faceRuleMapper.selectFaceRuleList(faceRule);
    }

    /**
     * 新增rule
     *
     * @param faceRule rule
     * @return 结果
     */
    @Override
    public int insertFaceRule(FaceRule faceRule)
    {
        return faceRuleMapper.insertFaceRule(faceRule);
    }

    /**
     * 修改rule
     *
     * @param faceRule rule
     * @return 结果
     */
    @Override
    public int updateFaceRule(FaceRule faceRule)
    {
        return faceRuleMapper.updateFaceRule(faceRule);
    }

    /**
     * 批量删除rule
     *
     * @param ftrxs 需要删除的rule主键
     * @return 结果
     */
    @Override
    public int deleteFaceRuleByFtrxs(String[] ftrxs)
    {
        return faceRuleMapper.deleteFaceRuleByFtrxs(ftrxs);
    }

    /**
     * 删除rule信息
     *
     * @param ftrx rule主键
     * @return 结果
     */
    @Override
    public int deleteFaceRuleByFtrx()
    {
        return faceRuleMapper.deleteFaceRuleByFtrx();
    }
}
